package com.huiju.estateagents.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.entity.TaLiveActivity;
import com.huiju.estateagents.entity.TaMiniapp;
import com.huiju.estateagents.entity.TaShareContent;
import com.huiju.estateagents.mapper.TaLiveActivityMapper;
import com.huiju.estateagents.service.IMiniAppService;
import com.huiju.estateagents.service.ITaLiveActivityService;
import com.huiju.estateagents.service.ITaMiniappService;
import com.huiju.estateagents.service.TaShareContentService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2020-02-20
 */
@Service
public class TaLiveActivityServiceImpl extends ServiceImpl<TaLiveActivityMapper, TaLiveActivity> implements ITaLiveActivityService {

    private Logger logger = LoggerFactory.getLogger(TaLiveActivityServiceImpl.class);

    @Autowired
    private TaShareContentService taShareContentService;

    @Autowired
    private ITaMiniappService taMiniappService;

    @Autowired
    private IMiniAppService miniAppService;

    @Autowired
    private TaLiveActivityMapper taLiveActivityMapper;


    @Override
    public ResponseBean taLiveActivityAdd(TaLiveActivity taLiveActivity) {
        logger.info("TaLiveActivityServiceImpl.taLiveActivityAdd 接收参数：" + JSONObject.toJSONString(taLiveActivity));

        ResponseBean responseBean = new ResponseBean();

        taLiveActivity.setVisitNum(0);
        taLiveActivity.setCreateDate(LocalDateTime.now());
        taLiveActivity.setUpdateDate(LocalDateTime.now());
        Boolean result = save(taLiveActivity);
        if (!result) {
            responseBean.addError("fail");
            return responseBean;
        }

        // 生成二维码
        QueryWrapper<TaMiniapp> taMiniappQuery = new QueryWrapper<>();
        taMiniappQuery.eq("org_id", taLiveActivity.getOrgId());
        TaMiniapp taMiniapp = taMiniappService.getOne(taMiniappQuery);
        /**
         *  TODO 部分信息待修改
         */
        ResponseBean taMiniappQrcode = miniAppService.getQrCode
                (CommConstant.ACTIVITY_QRCODE.replace("#0", taLiveActivity.getLiveActivityId().toString())
                        .replace("#1", "live"), taMiniapp.getMiniappId());
        taLiveActivity.setQrCode(String.valueOf(taMiniappQrcode.getData()));
        updateById(taLiveActivity);

        // 设置默认海报数据
        TaShareContent shareContent = new TaShareContent();
        shareContent.setOrgId(taLiveActivity.getOrgId());
        shareContent.setTargetId(taLiveActivity.getLiveActivityId().toString());
        shareContent.setShareContentTitle("直播看房，在线答疑，快上车~");
        shareContent.setShareContentImg(taLiveActivity.getDetailImg());
        shareContent.setShareContentType("live");
        shareContent.setStatus(1);
        shareContent.setCreateDate(LocalDateTime.now());
        taShareContentService.save(shareContent);

        responseBean.addSuccess(taLiveActivity);
        return responseBean;
    }

    @Override
    public ResponseBean listLiveActivityByCondition(Integer pageNum, Integer pageSize, Integer orgId, String liveActivityTitle,
                                                    String cityId, String buildingId, String liveDetailType, Integer status) {
        logger.info("TaLiveActivityServiceImpl.listLiveActivityByCondition 接收参数：pageNum:{},pageSize:{},orgId:{}," +
                    "liveActivityTitle:{},cityId:{},buildingId:{},liveDetailType:{},status:{}", pageNum, pageSize,
                liveActivityTitle, cityId, buildingId, liveDetailType, status);

        ResponseBean responseBean = new ResponseBean();
        IPage<TaLiveActivity> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaLiveActivity> queryWrapper = new QueryWrapper<>();
        queryWrapper.like("live_activity_title", liveActivityTitle);
        queryWrapper.eq("city_id", cityId);
        queryWrapper.eq("building_id", buildingId);
        queryWrapper.eq("live_detail_type", liveDetailType);
        queryWrapper.eq("status", status);
        queryWrapper.orderByDesc("create_date");
        IPage<TaLiveActivity> result = page(pg, queryWrapper);
        responseBean.addSuccess(result);
        return responseBean;
    }

    @Override
    public ResponseBean addVisitNum(String id) {
        ResponseBean responseBean = new ResponseBean();
        Boolean result = taLiveActivityMapper.addVisitNum(id);
        if(result){
            responseBean.addSuccess("成功");
            return responseBean;
        }
        responseBean.addError("fail");
        return responseBean;
    }
}
